=======
Credits
=======

Development Lead
----------------

* Stefan Ecklebe <stefan.ecklebe@tu-dresden.de>
* Christoph Burggraf <chris.burggraf@web.de>

Contributors
------------

* Marcus Riesmeier
* Jonas Hoffmann
